====================
craytraverse (0.1.5)
====================

.. image:: https://img.shields.io/pypi/v/craytraverse?style=flat-square
    :target: https://pypi.org/project/craytraverse
    :alt: PyPI

.. image:: https://img.shields.io/pypi/l/craytraverse?style=flat-square
    :target: https://www.mozilla.org/en-US/MPL/2.0/
    :alt: PyPI - License

c/c++ libraries for raytraverse, including radiance based render classes.

* Free software: Mozilla Public License 2.0 (MPL 2.0)
* Documentation: https://raytraverse.readthedocs.io/en/latest/.


Installation
------------
The easiest way to install craytraverse is with pip::

    pip install --upgrade pip setuptools wheel
    pip install craytraverse

or if you have cloned this repository::

    cd path/to/this/file
    git submodule init
    git submodule update
    pip install .

